@@ -1,9 +1,9 @@
 import os
 import json
+import unittest
 
 import pyexcel as pe
 
-import unittest
 from nose.tools import eq_, raises
 
 
@@ -68,10 +68,12 @@ class PyexcelSheetBase(unittest.TestCase):
     filename = "fixtures/non-uniform-rows.csv"
 
     def setUp(self):
-        self.sheet = pe.Sheet([
-            [f"{row_no}_{col_no}" for col_no in range(10)]
-            for row_no in range(10)
-        ])
+        self.sheet = pe.Sheet(
+            [
+                [f"{row_no}_{col_no}" for col_no in range(10)]
+                for row_no in range(10)
+            ]
+        )
 
 
 class PyexcelBase:
@@ -154,7 +156,7 @@ class PyexcelMultipleSheetBase:
         expected = [[4, 4, 4, 4], [5, 5, 5, 5], [6, 6, 6, 6]]
         assert data == expected
         data = list(b["Sheet3"].rows())
-        expected = [[u"X", u"Y", u"Z"], [1, 4, 7], [2, 5, 8], [3, 6, 9]]
+        expected = [["X", "Y", "Z"], [1, 4, 7], [2, 5, 8], [3, 6, 9]]
         assert data == expected
         sheet3 = b["Sheet3"]
         sheet3.name_columns_by_row(0)
