@@ -1,7 +1,7 @@
 import os
 
-import pyexcel.internal.garbagecollector as gc
 from pyexcel import iget_array
+from pyexcel.internal import garbagecollector as gc
 
 from nose.tools import eq_
 
