@@ -4,8 +4,8 @@ from pyexcel.internal.common import get_sheet_headers
 from pyexcel.internal.generators import SheetStream
 from pyexcel.plugins.sources.output_to_memory import WriteSheetToMemory
 
-import pyexcel_io.manager as manager
 from nose.tools import eq_
+from pyexcel_io import manager as manager
 
 
 def test_save_to():
